GitLab
======

`GitLab <https://gitlab.com/>`__ is available at `lab.example.com`.
The user with administrative rights is `root`. Its password can be set
as documented in `this file
<https://lab.enough.community/main/infrastructure/blob/master/inventory/group_vars/gitlab/gitlab.yml>`__
and can be modified in the
`~/.enough/example.com/inventory/group_vars/gitlab/gitlab.yml`
file.
